@@ -18,9 +18,12 @@ use crate::{
         ParquetToDataFrame, ReadToDataFrames, Source, SqliteToDataFrames,
     },
     tui::{
-        TabContentState, TableType, data_frame_info::DataFrameInfoState,
-        data_frame_table::DataFrameTableState, histogram_plot::HistogramPlotState,
-        scatter_plot::ScatterPlotState, search_bar::SearchBarState, tab_content::Modal,
+        TabContentState, TableType,
+        data_frame_table::DataFrameTableState,
+        plots::{histogram_plot::HistogramPlotState, scatter_plot::ScatterPlotState},
+        schema::data_frame_info::DataFrameInfoState,
+        search_bar::SearchBarState,
+        tab_content::Modal,
     },
     writer::{
         Destination, JsonFormat, WriteToArrow, WriteToCsv, WriteToFile, WriteToJson, WriteToParquet,
@@ -70,10 +73,14 @@ pub enum AppAction {
 
     PaletteGotoNext,
     PaletteGotoPrev,
+    PaletteGotoNextWord,
+    PaletteGotoPrevWord,
     PaletteGotoStart,
     PaletteGotoEnd,
     PaletteDeleteNext,
     PaletteDeletePrev,
+    PaletteDeleteNextWord,
+    PaletteDeletePrevWord,
     PaletteInsert(char),
     PaletteInsertSelectedOrCommit,
     PaletteShow(String),
@@ -85,10 +92,14 @@ pub enum AppAction {
     SearchExactShow,
     SearchGotoNext,
     SearchGotoPrev,
+    SearchGotoNextWord,
+    SearchGotoPrevWord,
     SearchGotoStart,
     SearchGotoEnd,
     SearchDeleteNext,
     SearchDeletePrev,
+    SearchDeleteNextWord,
+    SearchDeletePrevWord,
     SearchInsert(char),
     SearchRollback,
     SearchCommit,
@@ -149,7 +160,9 @@ pub enum AppAction {
 
     ScatterPlot(String, String, Vec<String>),
 
-    HistogramPlot(String),
+    HistogramPlot(String, usize),
+    HistogramScrollUp,
+    HistogramScrollDown,
 
     RegisterDataFrame(String),
     Help,
@@ -492,7 +505,7 @@ pub fn execute(action: AppAction, app: &mut App) -> AppResult<Option<AppAction>>
             )))
         }
         AppAction::ImportSqlite(source) => {
-            let frames = SqliteToDataFrames.named_frames(source.clone())?;
+            let frames = SqliteToDataFrames::default().named_frames(source.clone())?;
             for (name, df) in frames {
                 let name = sql().register(&name, df.clone(), source.clone());
                 app.tabs_mut()
@@ -546,6 +559,28 @@ pub fn execute(action: AppAction, app: &mut App) -> AppResult<Option<AppAction>>
             }
             Ok(None)
         }
+        AppAction::SearchGotoNextWord => {
+            if let Some(sb) = app
+                .tabs_mut()
+                .selected_mut()
+                .map(TabContentState::modal_mut)
+                .and_then(Modal::search_bar_mut)
+            {
+                sb.goto_next_word();
+            }
+            Ok(None)
+        }
+        AppAction::SearchGotoPrevWord => {
+            if let Some(sb) = app
+                .tabs_mut()
+                .selected_mut()
+                .map(TabContentState::modal_mut)
+                .and_then(Modal::search_bar_mut)
+            {
+                sb.goto_prev_word();
+            }
+            Ok(None)
+        }
         AppAction::SearchGotoStart => {
             if let Some(sb) = app
                 .tabs_mut()
@@ -590,6 +625,28 @@ pub fn execute(action: AppAction, app: &mut App) -> AppResult<Option<AppAction>>
             }
             Ok(None)
         }
+        AppAction::SearchDeleteNextWord => {
+            if let Some(sb) = app
+                .tabs_mut()
+                .selected_mut()
+                .map(TabContentState::modal_mut)
+                .and_then(Modal::search_bar_mut)
+            {
+                sb.delete_next_word();
+            }
+            Ok(None)
+        }
+        AppAction::SearchDeletePrevWord => {
+            if let Some(sb) = app
+                .tabs_mut()
+                .selected_mut()
+                .map(TabContentState::modal_mut)
+                .and_then(Modal::search_bar_mut)
+            {
+                sb.delete_prev_word();
+            }
+            Ok(None)
+        }
         AppAction::SearchInsert(c) => {
             if let Some(sb) = app
                 .tabs_mut()
@@ -710,6 +767,18 @@ pub fn execute(action: AppAction, app: &mut App) -> AppResult<Option<AppAction>>
             }
             Ok(None)
         }
+        AppAction::PaletteGotoNextWord => {
+            if let Some(palette) = app.palette_mut() {
+                palette.input().goto_next_word();
+            }
+            Ok(None)
+        }
+        AppAction::PaletteGotoPrevWord => {
+            if let Some(palette) = app.palette_mut() {
+                palette.input().goto_prev_word();
+            }
+            Ok(None)
+        }
         AppAction::PaletteGotoEnd => {
             if let Some(palette) = app.palette_mut() {
                 palette.input().goto_end();
@@ -728,6 +797,18 @@ pub fn execute(action: AppAction, app: &mut App) -> AppResult<Option<AppAction>>
             }
             Ok(None)
         }
+        AppAction::PaletteDeleteNextWord => {
+            if let Some(palette) = app.palette_mut() {
+                palette.input().delete_next_word();
+            }
+            Ok(None)
+        }
+        AppAction::PaletteDeletePrevWord => {
+            if let Some(palette) = app.palette_mut() {
+                palette.input().delete_prev_word();
+            }
+            Ok(None)
+        }
         AppAction::PaletteInsert(c) => {
             if let Some(palette) = app.palette_mut() {
                 palette.input().insert(c);
@@ -1000,14 +1081,30 @@ pub fn execute(action: AppAction, app: &mut App) -> AppResult<Option<AppAction>>
             }
             Ok(None)
         }
-        AppAction::HistogramPlot(group_by) => {
+        AppAction::HistogramPlot(group_by, buckets) => {
             if let Some(tab_content) = app.tabs_mut().selected_mut() {
                 let df = tab_content.table().data_frame();
                 *tab_content.modal_mut() = Modal::HistogramPlot(HistogramPlotState::new(
-                    df.histogram_plot_data(&group_by, 24)?,
+                    df.histogram_plot_data(&group_by, buckets)?,
                 ))
             }
             Ok(None)
         }
+        AppAction::HistogramScrollUp => {
+            if let Some(tab_content) = app.tabs_mut().selected_mut() {
+                if let Modal::HistogramPlot(hist) = tab_content.modal_mut() {
+                    hist.scroll_up();
+                }
+            }
+            Ok(None)
+        }
+        AppAction::HistogramScrollDown => {
+            if let Some(tab_content) = app.tabs_mut().selected_mut() {
+                if let Modal::HistogramPlot(hist) = tab_content.modal_mut() {
+                    hist.scroll_down();
+                }
+            }
+            Ok(None)
+        }
     }
 }
