@@ -182,6 +182,8 @@ impl Default for KeyHandler {
 
         // ----- table keybindings
         hndl.keybinds(Context::Table)
+            // Q
+            .add(Keybind::default().char('Q').action(AppAction::Quit))
             // q
             .add(
                 Keybind::default()
@@ -289,7 +291,7 @@ impl Default for KeyHandler {
             )
             .add(
                 Keybind::default()
-                    .char('d')
+                    .char('f')
                     .ctrl()
                     .action(AppAction::TableGoDownFullPage),
             )
@@ -484,6 +486,42 @@ impl Default for KeyHandler {
                     .code(KeyCode::Delete)
                     .action(AppAction::PaletteDeleteNext),
             )
+            .add(
+                Keybind::default()
+                    .char('w')
+                    .alt()
+                    .action(AppAction::PaletteGotoPrevWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('e')
+                    .alt()
+                    .action(AppAction::PaletteGotoNextWord),
+            )
+            .add(
+                Keybind::default()
+                    .code(KeyCode::Left)
+                    .alt()
+                    .shift()
+                    .action(AppAction::PaletteGotoPrevWord),
+            )
+            .add(
+                Keybind::default()
+                    .code(KeyCode::Delete)
+                    .action(AppAction::PaletteGotoNextWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('d')
+                    .alt()
+                    .action(AppAction::PaletteDeletePrevWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('f')
+                    .alt()
+                    .action(AppAction::PaletteDeleteNextWord),
+            )
             // change selection
             .add(
                 Keybind::default()
@@ -583,12 +621,14 @@ impl Default for KeyHandler {
                     .code(KeyCode::Enter)
                     .action(AppAction::TabPanelSelect),
             )
+            .add(Keybind::default().char('Q').action(AppAction::Quit))
             .add(Keybind::default().char('q').action(AppAction::TabHidePanel))
             .add(
                 Keybind::default()
                     .code(KeyCode::Esc)
                     .action(AppAction::TabHidePanel),
             );
+
         // ---- search keybindings
         hndl.keybinds(Context::Search)
             // left right home end backspace delete
@@ -633,6 +673,45 @@ impl Default for KeyHandler {
                     .code(KeyCode::Esc)
                     .action(AppAction::SearchRollback),
             )
+            // alt-(w/e/left/right)
+            .add(
+                Keybind::default()
+                    .code(KeyCode::Left)
+                    .alt()
+                    .shift()
+                    .action(AppAction::SearchGotoPrevWord),
+            )
+            .add(
+                Keybind::default()
+                    .code(KeyCode::Right)
+                    .alt()
+                    .shift()
+                    .action(AppAction::SearchGotoNextWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('w')
+                    .alt()
+                    .action(AppAction::SearchGotoPrevWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('e')
+                    .alt()
+                    .action(AppAction::SearchGotoNextWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('d')
+                    .alt()
+                    .action(AppAction::SearchDeletePrevWord),
+            )
+            .add(
+                Keybind::default()
+                    .char('f')
+                    .alt()
+                    .action(AppAction::SearchDeleteNextWord),
+            )
             // insert characters
             .fallback(|event| {
                 if let KeyCode::Char(c) = event.code {
@@ -678,6 +757,7 @@ impl Default for KeyHandler {
                     .code(KeyCode::Esc)
                     .action(AppAction::TableDismissModal),
             );
+
         // ---- scatter plot keybindings
         hndl.keybinds(Context::ScatterPlot)
             // q esc
@@ -691,8 +771,31 @@ impl Default for KeyHandler {
                     .code(KeyCode::Esc)
                     .action(AppAction::TableDismissModal),
             );
+
         // ---- histogram plot keybindings
         hndl.keybinds(Context::HistogramPlot)
+            // up down
+            .add(
+                Keybind::default()
+                    .code(KeyCode::Up)
+                    .action(AppAction::HistogramScrollUp),
+            )
+            .add(
+                Keybind::default()
+                    .code(KeyCode::Down)
+                    .action(AppAction::HistogramScrollDown),
+            )
+            // jk
+            .add(
+                Keybind::default()
+                    .char('k')
+                    .action(AppAction::HistogramScrollUp),
+            )
+            .add(
+                Keybind::default()
+                    .char('j')
+                    .action(AppAction::HistogramScrollDown),
+            )
             // q esc
             .add(
                 Keybind::default()
