@@ -8,30 +8,48 @@ use polars::{
 use rusqlite::Connection;
 use tempfile::NamedTempFile;
 
-use crate::{AppResult, misc::globals::stdin};
+use crate::{AppResult, args::Args, misc::globals::stdin, reader::Source};
 
 use super::{NamedFrames, ReadToDataFrames};
 
-pub struct SqliteToDataFrames;
+#[derive(Default)]
+pub struct SqliteToDataFrames {
+    key: Option<String>,
+}
+
+impl SqliteToDataFrames {
+    pub fn from_args(args: &Args) -> Self {
+        Self {
+            key: args.sqlite_key.clone(),
+        }
+    }
+
+    pub fn key(key: String) -> Self {
+        SqliteToDataFrames { key: Some(key) }
+    }
+}
 
 impl ReadToDataFrames for SqliteToDataFrames {
     fn named_frames(&self, input: super::Source) -> AppResult<NamedFrames> {
         match input {
-            crate::reader::Source::File(path) => path_to_name_frames(path),
-            crate::reader::Source::Stdin => {
+            Source::File(path) => path_to_name_frames(path, self.key.as_deref()),
+            Source::Stdin => {
                 let temp_file = NamedTempFile::new()?;
                 let mut buf = Vec::new();
                 stdin().read_to_end(&mut buf).unwrap();
                 std::fs::write(temp_file.path(), buf).unwrap();
-                path_to_name_frames(temp_file.path())
+                path_to_name_frames(temp_file.path(), self.key.as_deref())
             }
         }
     }
 }
 
-fn path_to_name_frames(path: impl AsRef<Path>) -> AppResult<NamedFrames> {
+fn path_to_name_frames(path: impl AsRef<Path>, key: Option<&str>) -> AppResult<NamedFrames> {
     let conn = Connection::open(path)?;
 
+    if let Some(key) = key {
+        conn.pragma_update(None, "key", key)?;
+    }
     // Fetch table names
     let names = conn
         .prepare("SELECT name FROM sqlite_master WHERE type='table' AND name NOT LIKE 'sqlite_%';")?
